package models

import (
	"ims/util/db/dts"
	"mime/multipart"
	"time"

	"gorm.io/gorm"
)

const (
	FileForSupplierContract = "supplier-contract" // 供应商合同附件
	FileForCertification    = "certification"     // 资质文件
)

// File 上传的文件
type File struct {
	ID           uint           `json:"id" gorm:"primarykey"`  // 标签编号
	RawID        dts.NullUint   `json:"raw_id"`                // 原始文件编号
	OwnerID      uint           `json:"owner_id"`              // 所属者编号
	OwnerType    string         `json:"owner_type"`            // 所属者类型
	IsDir        bool           `json:"is_dir"`                // 是不是目录
	Size         uint           `json:"size"`                  // 文件大小
	Name         string         `json:"name"`                  // 文件名称
	Mime         string         `json:"mime"`                  // 文件的MIME类型
	UploaderID   uint           `json:"uploader_id"`           // 上传者编号
	UploaderType string         `json:"uploader_type"`         // 上传者类型
	CreatedAt    time.Time      `json:"create_time"`           // 创建时间
	UpdatedAt    time.Time      `json:"update_time"`           // 上次更新时间
	DeletedAt    gorm.DeletedAt `json:"delete_time,omitempty"` // 数据删除时间`

	Base64File    any            `json:"-" gorm:"-"` // 上传的base64文件
	MultipartFile multipart.File `json:"-" gorm:"-"` // 上传的文件
}
