package models

import (
	"ims/util/db/dts"
	"time"

	"gorm.io/gorm"
)

type ModelTacking struct {
	ID        uint           `json:"id" gorm:"primarykey"`                   // 追踪ID
	Sequence  uint           `json:"sequence"`                               // 追踪的序列
	ModelName string         `json:"model_name"`                             // 追踪的模型名称
	RowID     uint           `json:"row_id"`                                 // 追踪的模型ID
	FieldName string         `json:"field_name"`                             // 追踪的字段名称
	OldValue  string         `json:"old_value"`                              // 旧值
	NewValue  string         `json:"new_value"`                              // 新值
	CreatedBy uint           `json:"created_by"`                             // 创建者（员工编号）
	CreatedAt time.Time      `json:"created_at"`                             // 创建时间
	UpdatedBy dts.NullUint   `json:"updated_by"`                             // 创建者（员工编号）
	UpdatedAt dts.NullTime   `json:"updated_at" gorm:"autoUpdateTime:false"` // 上次操作时间
	DeletedBy dts.NullUint   `json:"deleted_by"`                             // 删除者（员工编号）
	DeletedAt gorm.DeletedAt `json:"deleted_at" gorm:"index"`                // 删除数据时间

	Creator *Employee `json:"creator,omitempty" gorm:"foreignKey:CreatedBy"` // 创建数据的员工
	Updater *Employee `json:"updater,omitempty" gorm:"foreignKey:UpdatedBy"` // 上次更新数据的员工
	Deleter *Employee `json:"deleter,omitempty" gorm:"foreignKey:DeletedBy"` // 删除数据的员工
}
