package models

import (
	"ims/util/db/dts"
	"time"

	"gorm.io/gorm"
)

// ProductCategory 产品分类
type ProductCategory struct {
	ID   uint   `json:"id"   gorm:"primarykey"`  // 类型ID
	Name string `json:"name" gorm:"uniqueIndex"` // 类型名称
	Sort int    `json:"sort"`                    // 分类排序

	CreatedBy uint           `json:"created_by"`              // 创建者（员工编号）
	CreatedAt time.Time      `json:"created_at"`              // 创建时间
	UpdatedBy dts.NullUint   `json:"updated_by"`              // 创建者（员工编号）
	UpdatedAt time.Time      `json:"updated_at"`              // 上次操作时间
	DeletedBy dts.NullUint   `json:"deleted_by"`              // 删除者（员工编号）
	DeletedAt gorm.DeletedAt `json:"deleted_at" gorm:"index"` // 删除数据时间

	Creator *Employee `json:"creator,omitempty" gorm:"foreignKey:CreatedBy"` // 创建数据的员工
	Updater *Employee `json:"updater,omitempty" gorm:"foreignKey:UpdatedBy"` // 上次更新数据的员工
	Deleter *Employee `json:"deleter,omitempty" gorm:"foreignKey:DeletedBy"` // 删除数据的员工
}
