package models

import (
	"ims/util/db/dts"
	"time"

	"gorm.io/gorm"
)

// PurchaseAudit 采购审核
//
// 可以对采购申请驳回，所以一个采购申请会存在多次审核
type PurchaseAudit struct {
	ID            uint           `json:"id" gorm:"primaryKey"` // 审核ID
	RequisitionID uint           `json:"requisition_id"`       // 采购单ID
	AuditorID     uint           `json:"auditor_id"`           // 审核人ID（公司员工）
	DepartmentID  uint           `json:"department_id"`        // 审批人归属部门ID
	Result        bool           `json:"result"`               // 审批结果 - true审批通过、false不通过
	FailureReason dts.NullString `json:"failure_reason"`       // 不通过原因

	Requisition *PurchaseRequisition `json:"requisition,omitempty" gorm:"foreignKey:RequisitionID"` // 所属采购请求
	Auditor     *Employee            `json:"auditor,omitempty"     gorm:"foreignKey:AuditorID"`     // 审核人
	Department  *Department          `json:"department,omitempty"  gorm:"foreignKey:DepartmentID"`  // 审批人归属部门

	// 数据操作
	CreatedBy uint           `json:"created_by"`                             // 创建者（员工编号）
	CreatedAt time.Time      `json:"created_at"`                             // 创建时间
	UpdatedBy dts.NullUint   `json:"updated_by"`                             // 创建者（员工编号）
	UpdatedAt dts.NullTime   `json:"updated_at" gorm:"autoUpdateTime:false"` // 上次操作时间
	DeletedBy dts.NullUint   `json:"deleted_by"`                             // 删除者（员工编号）
	DeletedAt gorm.DeletedAt `json:"deleted_at" gorm:"index"`                // 删除数据时间

	Creator *Employee `json:"creator,omitempty" gorm:"foreignKey:CreatedBy"` // 创建数据的员工
	Updater *Employee `json:"updater,omitempty" gorm:"foreignKey:UpdatedBy"` // 上次更新数据的员工
	Deleter *Employee `json:"deleter,omitempty" gorm:"foreignKey:DeletedBy"` // 删除数据的员工
}
