package models

import (
	"time"

	"gorm.io/gorm"
)

type TaxType int8

// 针对供应商
const (
	_ TaxType = iota + 1 // 增值税专用发票
	_                    // 增值税普通发票
)

// 正对消费者
const (
	_ TaxType = iota + 3 // 纸质专票
	_                    // 纸质普票
	_                    // 电子普票
	_                    // 电子专票
	_                    // 全电专票
	_                    // 全电普票
	_                    // 无需开票
)

const (
	RemittanceForCustomer = "customer" // 消费者
	RemittanceForSupplier = "supplier" // 供应商
)

// Remittance 汇款信息
type Remittance struct {
	ID            uint           `json:"id" gorm:"primarykey"`  // 汇款信息编号
	OwnerID       uint           `json:"owner_id"`              // 所属者编号
	OwnerType     string         `json:"owner_type"`            // 所属者类型
	InvoiceTitle  string         `json:"invoice_title"`         // 发票抬头
	InvoiceNumber string         `json:"invoice_number"`        // 发票税号
	TaxType       TaxType        `json:"tax_type"`              // 税种
	TaxRate       int            `json:"tax_rate"`              // 增值税税率%
	BlankAccount  string         `json:"blank_account"`         // 银行账户
	BankName      string         `json:"blank_name"`            // 开户银行
	Telephone     string         `json:"telephone"`             // 开户电话
	Email         string         `json:"email"`                 // 收票邮箱
	CreatedAt     time.Time      `json:"create_time"`           // 创建时间
	UpdatedAt     time.Time      `json:"update_time"`           // 上次更新时间
	DeletedAt     gorm.DeletedAt `json:"delete_time,omitempty"` // 数据删除时间
}
